Attribute VB_Name = "Module0"
'//
'// Module API
'//

'// API DECLARATIONS /////////////////////////////////////////////////////////////////////////
'// Descriptions from http://www.vbapi.com

Option Explicit

Declare Function GetTickCount Lib "kernel32" () As Long

' Description & Usage:
'   GetTickCount determines how much time has elapsed since Windows was last started. _
    The time is measured in milliseconds, although the actual resolution of the function's _
    output depends on that of the system timer itself. Therefore, it may not be perfectly _
    accurate to the millisecond. Because of the limitations of the 32-bit integer data type, _
    the reported elapsed time wraps back to zero after about 49.7 days of continuous operation.
' Return Value:
'   The function returns the number of milliseconds that have passed since Windows was _
    last started.
   
Declare Function BitBlt Lib "gdi32" _
                (ByVal hDestDC As Long, _
                 ByVal x As Long, ByVal y As Long, _
                 ByVal nWidth As Long, ByVal nHeight As Long, _
                 ByVal hSrcDC As Long, _
                 ByVal xSrc As Long, ByVal ySrc As Long, _
                 ByVal dwRop As Long) As Long

Public Const SRCCOPY = &HCC0020
Public Const SRCAND = &H8800C6
Public Const MERGEPAINT = &HBB0226

' Description & Usage:
'   BitBlt performs a bit-block transfer of a rectangular portion of an image from one _
    device to another. The dimensions of the transfered rectangle are perfectly preserved. _
    The function can perform a variety of raster operations to transfer the block from the _
    source device to the target device.
' Return Value:
'   If an error occured, the function returns 0 (Windows NT, 2000: use GetLastError to get _
    the error code). If successful, the function returns a non-zero value.
' Visual Basic-Specific Issues:
'   None.
' Parameters:
'       hdcDest:
'               A handle to the device context of the device which receives the transfered _
                image block.
'       nXDest:
'               The x-coordinate of the point to position the upper-left corner of the _
                transfered image block.
'       nYDest:
'               The y-coordinate of the point to position the upper-left corner of the _
                transfered image block.
'       nWidth:
'               The width in pixels of the image block.
'       nHeight:
'               The height in pixels of the image block.
'       hdcSrc:
'               A handle to the device context of the device which contains the image block _
                to transfer.
'       nXSrc:
'               The x-coordinate of the upper-left corner of the image block to transfer.
'       nYSrc:
'               The y-coordinate of the upper-left corner of the image block to transfer.
'       dwRop:
'               One of the following flags identifying the raster operation to use to _
                transfer the image block. Each raster operation uses the RGB color value of _
                the source and/or target pixel to determine the new color of the target pixel.

'               BLACKNESS = &H42
'                   Fill the destination rectangle with the color whose index is 0 in the _
                    physical palette (which is black by default).
'               CAPTUREBLT = ???
'                   Windows 98, 2000: Include any windows layered on top of the window being _
                    used in the resulting image.
'               DSTINVERT = &H550009
'                   Invert the colors in the destination rectangle.
'               MERGECOPY = &HC000CA
'                   Merge the colors of the source rectangle with the specified pattern _
                    using the bitwise AND operator.
'               MERGEPAINT = &HBB0226
'                   Merge the colors of the inverted source rectangle with the colors of _
                    the destination rectangle using the bitwise OR operator.
'               NOMIRRORBITMAP = ????
'                   Windows 98, 2000: Prevent the bitmap from being mirrored.
'               NOTSRCCOPY = &H330008
'                   Copy the inverted source rectangle to the destination rectangle.
'               NOTSRCERASE = &H1100A6
'                   Combine the colors of the source and destination rectangles using the _
                    bitwise OR operator and then invert the resulting color.
'               PATCOPY = &HF00021
'                   Copy the specified pattern into the destination bitmap.
'               PATINVERT = &H5A0049
'                   Combine the colors of the specified pattern with the colors of the _
                    destination rectangle using the bitwise XOR operator.
'               PATPAINT = &HFB0A09
'                   Combine the colors of the specified pattern with the colors of the _
                    inverted source rectangle using the bitwise OR operator. Combine the _
                    result of that operation with the colors of the destination rectangle _
                    using the bitwise OR operator.
'               SRCAND = &H8800C6
'                   Combine the colors of the source and destination rectangles using the _
                    bitwise AND operator.
'               SRCCOPY = &HCC0020
'                   Copy the source rectangle directly into the destination rectangle.
'               SRCERASE = &H440328
'                   Combine the inverted colors of the destination rectangle with the _
                    colors of the source rectange using the bitwise AND operator.
'               SRCINVERT = &H660046
'                   Combine the colors of the source and destination rectangles using the _
                    bitwise XOR operator.
'               SRCPAINT = &HEE0086
'                   Combine the colors of the source and destination rectangles using the _
                    bitwise OR operator.
'               WHITENESS = &HFF0062
'                   Fill the destination rectangle with the color whose index is 1 in the _
                    physical palette (which is white by default).

Declare Function GetKeyState Lib "user32" _
                (ByVal nVirtKey As Long) As Integer
                
' Description & Usage:
'   GetKeyState determines the current status of a key. The function both finds whether _
    the key is currently pressed down or not, and determines if the key is currently toggled. _
    The keyboard information retrieved by this function is thread-specific; its information _
    does not necessarily reflect key states pertaining to the system as a whole.
' Return Value:
'   If the &H1 bit of the return value is set, the key is toggled. If the &H8000 bit of _
    the return value is set, the key is currently pressed down.

Declare Function TextOut Lib "gdi32" Alias "TextOutA" _
                (ByVal hdc As Long, _
                 ByVal x As Long, ByVal y As Long, _
                 ByVal lpString As String, ByVal nCount As Long) As Long
                        
' TextOut displays a line of text on a device. The relation of the text to the (x,y) pair _
  passed to the function can be set using SetTextAlign. The text will be displayed using _
  the device's currently selected font and text drawing color. The function returns 1 if _
  successful, or 0 if an error occured.

' hdc      : The device context of the device to display the line of text on.
' X        : The x coordinate of the reference point to display the text at.
' Y        : The y coordinate of the reference point to display the text at.
' lpString : The string to display on the device.
' nCount   : The size in characters of lpString.

Declare Function DrawText Lib "user32" Alias "DrawTextA" _
                (ByVal hdc As Long, _
                 ByVal lpStr As String, ByVal nCount As Long, _
                 lpRect As RECT, _
                 ByVal wFormat As Long) As Long
Type RECT
    Left As Long
    Top As Long
    Right As Long
    Bottom As Long
End Type

Public Const DT_CALCRECT = &H400
Public Const DT_CENTER = &H1
Public Const DT_WORDBREAK = &H10
                   
' No documentation
                                      
Declare Function PlaySound Lib "winmm.dll" Alias "PlaySoundA" _
                        (ByVal lpszName As String, _
                         ByVal hModule As Long, _
                         ByVal dwFlags As Long) As Long

Public Const SND_ASYNC = &H1
Public Const SND_NODEFAULT = &H2

' PlaySound plays a waveform sound through the speakers. This sound could be a .wav file, _
  a system event sound (such as the system startup sound), or a sound resource stored in _
  an application. Note that when the function needs to play an application resource or a _
  RAM-loaded sound, Visual Basic users must use the alternate declare of the function in _
  order to pass the numeric identifier of the sound instead of a string. The function _
  returns 0 if an error occured, or a non-zero value if successful.

' lpszName:
'       The name or some other identifier of the sound. Its exact format depends on _
        the flags passed as dwFlags.
' hModule:
'       A handle to the application module containing the sound resource the play, if _
        needed. If the function does not need this information, pass 0 for this parameter.
' dwFlags:
'       Zero or more of the following flags specifying what lpszName refers to and how _
        to play the sound:

'       SND_ALIAS = &H10000
'           lpszName is a string identifying the name of the system event sound to play.
'       SND_ALIAS_ID = &H110000
'           lpszName is a string identifying the name of the predefined sound identifier _
            to play.
'       SND_APPLICATION = &H80
'           lpszName is a string identifying the application-specific event association _
            sound to play.
'       SND_ASYNC = &H1
'           Play the sound asynchronously -- return immediately after beginning to play _
            the sound and have it play in the background.
'       SND_FILENAME = &H20000
'           lpszName is a string identifying the filename of the .wav file to play.
'       SND_LOOP = &H8
'           Continue looping the sound until this function is called again ordering the _
            looped playback to stop. SND_ASYNC must also be specified.
'       SND_MEMORY = &H4
'           lpszName is a numeric pointer refering to the memory address of the image of _
            the waveform sound loaded into RAM.
'       SND_NODEFAULT = &H2
'           If the specified sound cannot be found, terminate the function with failure _
            instead of playing the SystemDefault sound. If this flag is not specified, the _
            SystemDefault sound will play if the specified sound cannot be located and the _
            function will return with success.
'       SND_NOSTOP = &H10
'           If a sound is already playing, do not prematurely stop that sound from playing _
            and instead return with failure. If this flag is not specified, the playing _
            sound will be terminated and the sound specified by the function will play instead.
'       SND_NOWAIT = &H2000
'           If a sound is already playing, do not wait for the currently playing sound to _
            stop and instead return with failure.
'       SND_PURGE = &H40
'           Stop playback of any waveform sound. lpszName must be an empty string.
'       SND_RESOURCE = &H4004
'           lpszName is the numeric resource identifier of the sound stored in an application. _
            hModule must be specified as that application's module handle.
'       SND_SYNC = &H0
'           Play the sound synchronously -- do not return until the sound has finished playing.

